@@ -7,6 +7,7 @@ import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -47,6 +48,7 @@ public class IGuestUpdateGuestAdditions {
     @XmlElement(required = true)
     protected String source;
     protected List<String> arguments;
+    @XmlSchemaType(name = "string")
     protected List<AdditionsUpdateFlag> flags;
 
     /**
